Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'core/Option.php')
-rw-r--r--core/Option.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/core/Option.php b/core/Option.php
index 4275b8afa1..ab3a1c672f 100644
--- a/core/Option.php
+++ b/core/Option.php
@@ -82,15 +82,15 @@ class Piwik_Option
*
* @param string $name
* @param string $value
* @param int $autoload if set to 1, this option value will be automatically loaded; should be set to 1 for options that will always be used in the Piwik request.
*/
- public function set($name, $value, $autoload = 0)
+ public function set($name, $value, $autoLoad = 0)
{
- $autoload = (int)$autoload;
+ $autoLoad = (int)$autoLoad;
Piwik_Query('INSERT INTO `' . Piwik_Common::prefixTable('option') . '` (option_name, option_value, autoload) ' .
' VALUES (?, ?, ?) ' .
' ON DUPLICATE KEY UPDATE option_value = ?',
- array($name, $value, $autoload, $value));
+ array($name, $value, $autoLoad, $value));
$this->all[$name] = $value;
}
@@ -187,9 +187,9 @@ function Piwik_GetOption($name)
*
* @param string $name
* @param string $value
* @param int $autoload if set to 1, this option value will be automatically loaded; should be set to 1 for options that will always be used in the Piwik request.
*/
-function Piwik_SetOption($name, $value, $autoload = 0)
+function Piwik_SetOption($name, $value, $autoLoad = 0)
{
- Piwik_Option::getInstance()->set($name, $value, $autoload);
+ Piwik_Option::getInstance()->set($name, $value, $autoLoad);
}
@@ -82,15 +82,15 @@ class Piwik_Option
* @param string $name
* @param string $value
- * @param int $autoload if set to 1, this option value will be automatically loaded; should be set to 1 for options that will always be used in the Piwik request.
+ * @param int $autoLoad if set to 1, this option value will be automatically loaded; should be set to 1 for options that will always be used in the Piwik request.
*/
@@ -187,9 +187,9 @@ function Piwik_GetOption($name)
* @param string $name
* @param string $value
- * @param int $autoload if set to 1, this option value will be automatically loaded; should be set to 1 for options that will always be used in the Piwik request.
+ * @param int $autoLoad if set to 1, this option value will be automatically loaded; should be set to 1 for options that will always be used in the Piwik request.
*/